@@ -4,11 +4,12 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 from typing import List
+from mitosheet.types import StepsManagerType
 
 UNDO_EVENT = 'undo'
 UNDO_PARAMS: List[str] = []
 
-def execute_undo_update(steps_manager):
+def execute_undo_update(steps_manager: StepsManagerType) -> None:
     steps_manager.execute_undo()
 
 """
