@@ -36,7 +36,7 @@ from mitosheet._version import package_name
 
 from mitosheet.user.db import get_user_json_object, set_user_json_object
 from mitosheet.user.schemas import (UJ_CLOSED_FEEDBACK, UJ_EXPERIMENT, UJ_FEEDBACKS_V2,
-                                    UJ_INTENDED_BEHAVIOR,
+                                    UJ_INTENDED_BEHAVIOR, UJ_MITOSHEET_ENTERPRISE,
                                     UJ_MITOSHEET_LAST_FIFTY_USAGES,
                                     UJ_MITOSHEET_LAST_FIVE_USAGES,
                                     UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_RECEIVED_CHECKLISTS,
@@ -187,6 +187,18 @@ def upgrade_user_json_version_6_to_7(user_json_version_6: Dict[str, Any]) -> Dic
 
     return user_json_version_6
 
+def upgrade_user_json_version_7_to_8(user_json_version_7: Dict[str, Any]) -> Dict[str, Any]:
+    """
+    Adds the UJ_MITOSHEET_ENTERPRISE key, and sets it to False
+    """
+    # First, bump the version number
+    user_json_version_7[UJ_USER_JSON_VERSION] = 8
+
+    # Then, add the new enterprise key
+    user_json_version_7[UJ_MITOSHEET_ENTERPRISE] = False
+
+    return user_json_version_7
+
 def try_upgrade_user_json_to_current_version() -> None:
     user_json_object = get_user_json_object()
 
@@ -214,6 +226,8 @@ def try_upgrade_user_json_to_current_version() -> None:
         user_json_object = upgrade_user_json_version_5_to_6(user_json_object)
     if user_json_object[UJ_USER_JSON_VERSION] == 6:
         user_json_object = upgrade_user_json_version_6_to_7(user_json_object)
+    if user_json_object[UJ_USER_JSON_VERSION] == 7:
+        user_json_object = upgrade_user_json_version_7_to_8(user_json_object)
 
     # We always make sure that the experiment is the most up to date
     # version of the experiment
